phoneengine/phonemodel/inc/cpemessagehandler.h
changeset 1 838b0a10d15b
parent 0 5f000ab63145
child 9 8871b09be73b
child 21 92ab7f8d0eab
--- a/phoneengine/phonemodel/inc/cpemessagehandler.h	Mon Jan 18 20:18:27 2010 +0200
+++ b/phoneengine/phonemodel/inc/cpemessagehandler.h	Tue Jan 26 11:57:27 2010 +0200
@@ -504,10 +504,11 @@
         TInt HandleServiceEnabled();
         
         /**
          * Handles remote party information changed         
          * @since Series60_5.2         
          */
-        void HandleRemotePartyInfoChanged( );
+        void HandleRemotePartyInfoChanged( const TInt aCallId );
 
         /**
         * Handles swap message from the phone application
@@ -504,10 +504,11 @@
         
         /**
-         * Handles remote party information changed         
+         * Handles remote party information changed   
+         * @param aCallId is the identification number of the call.               
          * @since Series60_5.2         
          */